@@ -960,7 +960,7 @@ class Tensor(torch.Tensor):
             with torch._C.DisableTorchFunction():
                 res = super(torch.Tensor, self.view(a + tuple(self.shape[-2:]))).__matmul__(other.view(b + tuple(other.shape[-2:])))
             return res.as_subclass(Tensor).special_from_(self.shape[:-2])
-        return super().__matmul__(other, **kwargs).as_subclass(Tensor)
+        return super().__matmul__(other, **kwargs).as_subclass(Tensor).special_from_()
 
     def __op__(self, opname, other, **kwargs):
         if isinstance(other, torch.Tensor) and self.has_special or isinstance(other, Tensor) and other.has_special:
@@ -968,7 +968,7 @@ class Tensor(torch.Tensor):
             with torch._C.DisableTorchFunction():
                 res = getattr(super(torch.Tensor, self.view(a)), opname)(other.view(b))
             return res.as_subclass(Tensor).special_from_(self)
-        return getattr(super(), opname)(other, **kwargs).as_subclass(Tensor)
+        return getattr(super(), opname)(other, **kwargs).as_subclass(Tensor).special_from_()
 
     for op in '''
     add iadd radd
